nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

DebugTog

Struct DebugTog 

#[repr(transparent)]
pub struct DebugTog(pub u32);
USB PHY Debug Register

Tuple Fields

0: u32

Implementations

Source

impl DebugTog

pub const fn otgidpiolock(&self) -> bool

Once OTG ID from USBPHYx_STATUS_OTGID_STATUS, use this to hold the value

pub const fn set_otgidpiolock(&mut self, val: bool)

Once OTG ID from USBPHYx_STATUS_OTGID_STATUS, use this to hold the value

pub const fn debug_interface_hold(&self) -> bool

Use holding registers to assist in timing for external UTMI interface.

pub const fn set_debug_interface_hold(&mut self, val: bool)

Use holding registers to assist in timing for external UTMI interface.

pub const fn hstpulldown(&self) -> u8

Set bit 3 to 1 to pull down 15-KOhm on USB_DP line

pub const fn set_hstpulldown(&mut self, val: u8)

Set bit 3 to 1 to pull down 15-KOhm on USB_DP line

pub const fn enhstpulldown(&self) -> u8

Set bit 5 to 1 to override the control of the USB_DP 15-KOhm pulldown

pub const fn set_enhstpulldown(&mut self, val: u8)

Set bit 5 to 1 to override the control of the USB_DP 15-KOhm pulldown

pub const fn rsvd0(&self) -> u8

Reserved.

pub const fn set_rsvd0(&mut self, val: u8)

Reserved.

pub const fn tx2rxcount(&self) -> u8

Delay in between the end of transmit to the beginning of receive

pub const fn set_tx2rxcount(&mut self, val: u8)

Delay in between the end of transmit to the beginning of receive

pub const fn entx2rxcount(&self) -> bool

Set this bit to allow a countdown to transition in between TX and RX.

pub const fn set_entx2rxcount(&mut self, val: bool)

Set this bit to allow a countdown to transition in between TX and RX.

pub const fn rsvd1(&self) -> u8

Reserved.

pub const fn set_rsvd1(&mut self, val: u8)

Reserved.

pub const fn squelchresetcount(&self) -> u8

Delay in between the detection of squelch to the reset of high-speed RX.

pub const fn set_squelchresetcount(&mut self, val: u8)

Delay in between the detection of squelch to the reset of high-speed RX.

pub const fn rsvd2(&self) -> u8

Reserved.

pub const fn set_rsvd2(&mut self, val: u8)

Reserved.

pub const fn ensquelchreset(&self) -> bool

Set bit to allow squelch to reset high-speed receive.

pub const fn set_ensquelchreset(&mut self, val: bool)

Set bit to allow squelch to reset high-speed receive.

pub const fn squelchresetlength(&self) -> u8

Duration of RESET in terms of the number of 480-MHz cycles.

pub const fn set_squelchresetlength(&mut self, val: u8)

Duration of RESET in terms of the number of 480-MHz cycles.

pub const fn host_resume_debug(&self) -> bool

Choose to trigger the host resume SE0 with HOST_FORCE_LS_SE0 = 0 or UTMI_SUSPEND = 1.

pub const fn set_host_resume_debug(&mut self, val: bool)

Choose to trigger the host resume SE0 with HOST_FORCE_LS_SE0 = 0 or UTMI_SUSPEND = 1.

pub const fn clkgate(&self) -> bool

Gate Test Clocks

pub const fn set_clkgate(&mut self, val: bool)

Gate Test Clocks

pub const fn rsvd3(&self) -> bool

Reserved.

pub const fn set_rsvd3(&mut self, val: bool)

Reserved.