#[repr(transparent)]pub struct Rx(pub u32);Expand description
USB PHY Receiver Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Rx
impl Rx
Sourcepub const fn envadj(&self) -> u8
pub const fn envadj(&self) -> u8
The ENVADJ field adjusts the trip point for the envelope detector
Sourcepub const fn set_envadj(&mut self, val: u8)
pub const fn set_envadj(&mut self, val: u8)
The ENVADJ field adjusts the trip point for the envelope detector
Sourcepub const fn disconadj(&self) -> u8
pub const fn disconadj(&self) -> u8
The DISCONADJ field adjusts the trip point for the disconnect detector: 000 = Trip-Level Voltage is 0
Sourcepub const fn set_disconadj(&mut self, val: u8)
pub const fn set_disconadj(&mut self, val: u8)
The DISCONADJ field adjusts the trip point for the disconnect detector: 000 = Trip-Level Voltage is 0
Sourcepub const fn set_rxdbypass(&mut self, val: bool)
pub const fn set_rxdbypass(&mut self, val: bool)
0 = Normal operation