#[repr(transparent)]pub struct TxClr(pub u32);Expand description
USB PHY Transmitter Control Register
Tuple Fields
0: u32Implementations
Sourceimpl TxClr
impl TxClr
Sourcepub const fn d_cal(&self) -> u8
pub const fn d_cal(&self) -> u8
Resistor Trimming Code: 0000 = 0.16% 0111 = Nominal 1111 = +25%
Sourcepub const fn set_d_cal(&mut self, val: u8)
pub const fn set_d_cal(&mut self, val: u8)
Resistor Trimming Code: 0000 = 0.16% 0111 = Nominal 1111 = +25%
Sourcepub const fn txcal45dn(&self) -> u8
pub const fn txcal45dn(&self) -> u8
Decode to select a 45-Ohm resistance to the USB_DN output pin
Sourcepub const fn set_txcal45dn(&mut self, val: u8)
pub const fn set_txcal45dn(&mut self, val: u8)
Decode to select a 45-Ohm resistance to the USB_DN output pin
Sourcepub const fn txcal45dp(&self) -> u8
pub const fn txcal45dp(&self) -> u8
Decode to select a 45-Ohm resistance to the USB_DP output pin
Sourcepub const fn set_txcal45dp(&mut self, val: u8)
pub const fn set_txcal45dp(&mut self, val: u8)
Decode to select a 45-Ohm resistance to the USB_DP output pin
Sourcepub const fn usbphy_tx_edgectrl(&self) -> u8
pub const fn usbphy_tx_edgectrl(&self) -> u8
Controls the edge-rate of the current sensing transistors used in HS transmit
Sourcepub const fn set_usbphy_tx_edgectrl(&mut self, val: u8)
pub const fn set_usbphy_tx_edgectrl(&mut self, val: u8)
Controls the edge-rate of the current sensing transistors used in HS transmit