nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

TxSet

Struct TxSet 

#[repr(transparent)]
pub struct TxSet(pub u32);
USB PHY Transmitter Control Register

Tuple Fields

0: u32

Implementations

Source

impl TxSet

pub const fn d_cal(&self) -> u8

Resistor Trimming Code: 0000 = 0.16% 0111 = Nominal 1111 = +25%

pub const fn set_d_cal(&mut self, val: u8)

Resistor Trimming Code: 0000 = 0.16% 0111 = Nominal 1111 = +25%

pub const fn rsvd0(&self) -> u8

Reserved. Note: This bit should remain clear.

pub const fn set_rsvd0(&mut self, val: u8)

Reserved. Note: This bit should remain clear.

pub const fn txcal45dn(&self) -> u8

Decode to select a 45-Ohm resistance to the USB_DN output pin

pub const fn set_txcal45dn(&mut self, val: u8)

Decode to select a 45-Ohm resistance to the USB_DN output pin

pub const fn rsvd1(&self) -> u8

Reserved. Note: This bit should remain clear.

pub const fn set_rsvd1(&mut self, val: u8)

Reserved. Note: This bit should remain clear.

pub const fn txcal45dp(&self) -> u8

Decode to select a 45-Ohm resistance to the USB_DP output pin

pub const fn set_txcal45dp(&mut self, val: u8)

Decode to select a 45-Ohm resistance to the USB_DP output pin

pub const fn rsvd2(&self) -> u8

Reserved.

pub const fn set_rsvd2(&mut self, val: u8)

Reserved.

pub const fn usbphy_tx_edgectrl(&self) -> u8

Controls the edge-rate of the current sensing transistors used in HS transmit

pub const fn set_usbphy_tx_edgectrl(&mut self, val: u8)

Controls the edge-rate of the current sensing transistors used in HS transmit

pub const fn rsvd5(&self) -> u8

Reserved.

pub const fn set_rsvd5(&mut self, val: u8)

Reserved.